@@ -127,9 +127,16 @@ public class BroadCastStatsLogger {
                 }
 
                 @Override
-                public void add(long l) {
-                    firstCounter.add(l);
-                    secondCounter.add(l);
+                public void addCount(long l) {
+                    firstCounter.addCount(l);
+                    secondCounter.addCount(l);
+                }
+
+                @Override
+                public void addLatency(long eventLatency, TimeUnit unit) {
+                    long valueMillis = unit.toMillis(eventLatency);
+                    firstCounter.addCount(valueMillis);
+                    secondCounter.addCount(valueMillis);
                 }
 
                 @Override
