@@ -543,7 +543,7 @@ public class BookieImpl implements Bookie {
                             masterKeyCache.put(ledgerId, masterKey);
 
                             // Force to re-insert the master key in ledger storage
-                            handles.getHandle(ledgerId, masterKey);
+                            handles.getHandle(ledgerId, masterKey, true);
                         } else {
                             throw new IOException("Invalid journal. Contains journalKey "
                                     + " but layout version (" + journalVersion
@@ -555,7 +555,7 @@ public class BookieImpl implements Bookie {
                             if (key == null) {
                                 key = ledgerStorage.readMasterKey(ledgerId);
                             }
-                            LedgerDescriptor handle = handles.getHandle(ledgerId, key);
+                            LedgerDescriptor handle = handles.getHandle(ledgerId, key, true);
                             handle.setFenced();
                         } else {
                             throw new IOException("Invalid journal. Contains fenceKey "
@@ -573,7 +573,7 @@ public class BookieImpl implements Bookie {
                             if (key == null) {
                                 key = ledgerStorage.readMasterKey(ledgerId);
                             }
-                            LedgerDescriptor handle = handles.getHandle(ledgerId, key);
+                            LedgerDescriptor handle = handles.getHandle(ledgerId, key, true);
                             handle.setExplicitLac(explicitLacBuf);
                         } else {
                             throw new IOException("Invalid journal. Contains explicitLAC " + " but layout version ("
@@ -596,7 +596,7 @@ public class BookieImpl implements Bookie {
                         if (key == null) {
                             key = ledgerStorage.readMasterKey(ledgerId);
                         }
-                        LedgerDescriptor handle = handles.getHandle(ledgerId, key);
+                        LedgerDescriptor handle = handles.getHandle(ledgerId, key, true);
 
                         recBuff.rewind();
                         handle.addEntry(Unpooled.wrappedBuffer(recBuff));
@@ -933,7 +933,7 @@ public class BookieImpl implements Bookie {
             throws IOException, BookieException {
         final long ledgerId = entry.getLong(entry.readerIndex());
 
-        return handles.getHandle(ledgerId, masterKey);
+        return handles.getHandle(ledgerId, masterKey, false);
     }
 
     private Journal getJournal(long ledgerId) {
@@ -1042,7 +1042,7 @@ public class BookieImpl implements Bookie {
         ByteBuf explicitLACEntry = null;
         try {
             long ledgerId = entry.getLong(entry.readerIndex());
-            LedgerDescriptor handle = handles.getHandle(ledgerId, masterKey);
+            LedgerDescriptor handle = handles.getHandle(ledgerId, masterKey, false);
             synchronized (handle) {
                 entry.markReaderIndex();
                 handle.setExplicitLac(entry);
@@ -1131,7 +1131,7 @@ public class BookieImpl implements Bookie {
      */
     public CompletableFuture<Boolean> fenceLedger(long ledgerId, byte[] masterKey)
             throws IOException, BookieException {
-        LedgerDescriptor handle = handles.getHandle(ledgerId, masterKey);
+        LedgerDescriptor handle = handles.getHandle(ledgerId, masterKey, false);
         return handle.fenceAndLogInJournal(getJournal(ledgerId));
     }
 
