@@ -504,6 +504,10 @@ public class GarbageCollectorThread implements Runnable {
                     e.getMessage(), e);
             gcStats.getGcThreadRuntime().registerFailedEvent(
                     MathUtils.nowInNano() - threadStart, TimeUnit.NANOSECONDS);
+        } catch (Throwable e) {
+            LOG.error("Error in garbage collector thread, Failed to complete GC/Compaction due to {}",
+                e.getMessage(), e);
+            gcStats.getGcThreadRuntime().registerFailedEvent(MathUtils.elapsedNanos(threadStart), TimeUnit.NANOSECONDS);
         } finally {
             if (force && forceGarbageCollection.compareAndSet(true, false)) {
                 LOG.info("{} Set forceGarbageCollection to false after force GC to make it forceGC-able again.",
@@ -822,8 +826,13 @@ public class GarbageCollectorThread implements Runnable {
                     entryLogMetaMap.put(entryLogId, entryLogMeta);
                 }
             } catch (IOException | RuntimeException e) {
-                LOG.warn("Premature exception when processing " + entryLogId
-                         + " recovery will take care of the problem", e);
+                LOG.warn("Premature exception when processing {} recovery will take care of the problem",
+                        entryLogId, e);
+            } catch (OutOfMemoryError oome) {
+                // somewhat similar to https://github.com/apache/bookkeeper/pull/3901
+                // entrylog file can be corrupted but instead having a negative entry size
+                // it ends up with very large value for the entry size causing OODME
+                LOG.warn("OutOfMemoryError when processing {} - skipping the entry log", entryLogId, oome);
             }
         }
     }
