@@ -17,6 +17,7 @@
  */
 package org.apache.bookkeeper.bookie;
 
+import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Lists;
 import java.io.File;
 import java.io.FileNotFoundException;
@@ -51,6 +52,12 @@ public class LegacyCookieValidation implements CookieValidation {
         this.registrationManager = registrationManager;
     }
 
+    @VisibleForTesting
+    public static LegacyCookieValidation newLegacyCookieValidation(ServerConfiguration conf,
+                                                                   RegistrationManager registrationManager) {
+        return new LegacyCookieValidation(conf, registrationManager);
+    }
+
     @Override
     public void checkCookies(List<File> directories) throws BookieException {
         try {
