@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -15,9 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.bookkeeper.verifier;
 
 import static com.google.common.base.Preconditions.checkState;
+
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -301,7 +303,7 @@ public class BookkeeperVerifier {
 
         void openWrite(long entryID) {
             writesInProgress.add(entryID);
-            System.out.format("Open writes, %s%n", writesInProgress.toString());
+            System.out.format("Open writes, %s%n", writesInProgress);
         }
 
         void incReads() {
@@ -382,7 +384,7 @@ public class BookkeeperVerifier {
                 System.out.format(
                         "checkWriteComplete: ledger %d, writesInProgress %s%n",
                         ledgerID,
-                        writesInProgress.toString());
+                        writesInProgress);
                 cb.accept(0);
             }
         }
@@ -396,7 +398,7 @@ public class BookkeeperVerifier {
                 System.out.format(
                         "checkOpComplete: ledger %d, writesInProgress %s, readsInProgress %d%n",
                         ledgerID,
-                        writesInProgress.toString(), readsInProgress);
+                        writesInProgress, readsInProgress);
                 cb.accept(0);
             }
         }
