@@ -32,7 +32,6 @@ import java.util.concurrent.ThreadLocalRandom;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
-
 import org.apache.bookkeeper.conf.ClientConfiguration;
 import org.apache.bookkeeper.net.BookieId;
 import org.apache.bookkeeper.proto.BookieClientImpl;
@@ -92,8 +91,8 @@ public class SlowBookieTest extends BookKeeperClusterTestCase {
                 };
             lh.asyncAddEntry(entry, cb, null);
 
-            Thread.sleep(3000); // sleep 3 seconds to allow time to complete
-            assertEquals("Successfully added entry!", 0xdeadbeef, i.get());
+            Awaitility.await().untilAsserted(() ->
+                assertEquals("Successfully added entry!", 0xdeadbeef, i.get()));
             b0latch.countDown();
             b1latch.countDown();
             addEntrylatch.await(4000, TimeUnit.MILLISECONDS);
@@ -151,7 +150,9 @@ public class SlowBookieTest extends BookKeeperClusterTestCase {
         final AtomicInteger numFragments = new AtomicInteger(-1);
         lc.checkLedger(lh2, new GenericCallback<Set<LedgerFragment>>() {
                 public void operationComplete(int rc, Set<LedgerFragment> badFragments) {
-                    LOG.debug("Checked ledgers returned {} {}", rc, badFragments);
+                    if (LOG.isDebugEnabled()) {
+                        LOG.debug("Checked ledgers returned {} {}", rc, badFragments);
+                    }
                     if (rc == BKException.Code.OK) {
                         numFragments.set(badFragments.size());
                     }
@@ -177,8 +178,9 @@ public class SlowBookieTest extends BookKeeperClusterTestCase {
         final boolean expectWriteError = false;
         final boolean expectFailedTest = false;
 
-        LedgerHandle lh = doBackpressureTest(entry, conf, expectWriteError, expectFailedTest, 2000);
-        assertTrue(lh.readLastConfirmed() < 5);
+        try (LedgerHandle lh = doBackPressureTest(entry, conf, expectWriteError, expectFailedTest, 2000)) {
+            assertTrue(lh.readLastConfirmed() < 5);
+        }
     }
 
     @Test
@@ -196,8 +198,9 @@ public class SlowBookieTest extends BookKeeperClusterTestCase {
         final boolean expectWriteError = true;
         final boolean expectFailedTest = false;
 
-        LedgerHandle lh = doBackpressureTest(entry, conf, expectWriteError, expectFailedTest, 1000);
-        assertTrue(lh.readLastConfirmed() < 5);
+        try (LedgerHandle lh = doBackPressureTest(entry, conf, expectWriteError, expectFailedTest, 1000)) {
+            assertTrue(lh.readLastConfirmed() < 5);
+        }
     }
 
     @Test
@@ -215,14 +218,14 @@ public class SlowBookieTest extends BookKeeperClusterTestCase {
         final boolean expectWriteError = false;
         final boolean expectFailedTest = false;
 
-        LedgerHandle lh = doBackpressureTest(entry, conf, expectWriteError, expectFailedTest, 4000);
-
-        assertTrue(lh.readLastConfirmed() > 90);
+        try (LedgerHandle lh = doBackPressureTest(entry, conf, expectWriteError, expectFailedTest, 4000)) {
+            assertTrue(lh.readLastConfirmed() > 90);
+        }
     }
 
-    private LedgerHandle doBackpressureTest(byte[] entry, ClientConfiguration conf,
-                                    boolean expectWriteError, boolean expectFailedTest,
-                                    long sleepInMillis) throws Exception {
+    private LedgerHandle doBackPressureTest(byte[] entry, ClientConfiguration conf,
+                                            boolean expectWriteError, boolean expectFailedTest,
+                                            long sleepInMillis) throws Exception {
         BookKeeper bkc = new BookKeeper(conf);
 
         byte[] pwd = new byte[] {};
@@ -281,38 +284,39 @@ public class SlowBookieTest extends BookKeeperClusterTestCase {
 
         LedgerHandle lh2 = bkc.openLedger(lh.getId(), BookKeeper.DigestType.CRC32, pwd);
         LedgerChecker lc = new LedgerChecker(bkc);
-        final CountDownLatch checklatch = new CountDownLatch(1);
+        final CountDownLatch checkLatch = new CountDownLatch(1);
         final AtomicInteger numFragments = new AtomicInteger(-1);
         lc.checkLedger(lh2, (rc, fragments) -> {
-            LOG.debug("Checked ledgers returned {} {}", rc, fragments);
+            if (LOG.isDebugEnabled()) {
+                LOG.debug("Checked ledgers returned {} {}", rc, fragments);
+            }
             if (rc == BKException.Code.OK) {
                 numFragments.set(fragments.size());
                 LOG.error("Checked ledgers returned {} {}", rc, fragments);
             }
-            checklatch.countDown();
+            checkLatch.countDown();
         });
-        checklatch.await();
+        checkLatch.await();
         assertEquals("There should be no missing fragments", 0, numFragments.get());
 
         return lh2;
     }
 
     private void setTargetChannelState(BookKeeper bkc, BookieId address,
-                                       long key, boolean state) throws Exception {
+                                       long key, boolean writable) throws Exception {
         ((BookieClientImpl) bkc.getBookieClient()).lookupClient(address).obtain((rc, pcbc) -> {
-            pcbc.setWritable(state);
+            pcbc.setWritable(writable);
         }, key);
     }
 
     @Test
-    public void testWritesetWriteableCheck() throws Exception {
+    public void testWriteSetWriteableCheck() throws Exception {
         final ClientConfiguration conf = new ClientConfiguration();
         conf.setMetadataServiceUri(zkUtil.getMetadataServiceUri());
         BookKeeper bkc = new BookKeeper(conf);
 
         byte[] pwd = new byte[]{};
-        final LedgerHandle lh = bkc.createLedger(4, 2, 2, BookKeeper.DigestType.CRC32, pwd);
-        try {
+        try (LedgerHandle lh = bkc.createLedger(4, 2, 2, BookKeeper.DigestType.CRC32, pwd)) {
             lh.addEntry(entry); // [b0, b1]
             long entryId = lh.addEntry(entry); // [b1, b2]
 
@@ -330,9 +334,7 @@ public class SlowBookieTest extends BookKeeperClusterTestCase {
             setTargetChannelState(bkc, curEns.get(slowBookieIndex), 0, false);
 
             boolean isWriteable = lh.waitForWritable(writeSet, 0, 1000);
-            assertFalse("We should check b2,b3 both are writeable", isWriteable);
-        } finally {
-            lh.close();
+            assertFalse("We should check b2,b3 both are not writeable", isWriteable);
         }
     }
 
@@ -387,7 +389,9 @@ public class SlowBookieTest extends BookKeeperClusterTestCase {
         final AtomicInteger numFragments = new AtomicInteger(-1);
         lc.checkLedger(lh2, new GenericCallback<Set<LedgerFragment>>() {
                 public void operationComplete(int rc, Set<LedgerFragment> fragments) {
-                    LOG.debug("Checked ledgers returned {} {}", rc, fragments);
+                    if (LOG.isDebugEnabled()) {
+                        LOG.debug("Checked ledgers returned {} {}", rc, fragments);
+                    }
                     if (rc == BKException.Code.OK) {
                         numFragments.set(fragments.size());
                     }
@@ -421,11 +425,9 @@ public class SlowBookieTest extends BookKeeperClusterTestCase {
             final long timeout = 10000;
 
             // waitForWritable async
-           new Thread(() -> {
-                isWriteable.set(lh.waitForWritable(writeSet, 0, timeout));
-            }).start();
-            TimeUnit.MILLISECONDS.sleep(5000);
-            assertFalse(isWriteable.get());
+            new Thread(() -> isWriteable.set(lh.waitForWritable(writeSet, 0, timeout))).start();
+
+            Awaitility.await().pollDelay(5, TimeUnit.SECONDS).untilAsserted(() -> assertFalse(isWriteable.get()));
 
             // enable channel writable
             setTargetChannelState(bkc, curEns.get(slowBookieIndex), 0, true);
