@@ -96,6 +96,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
 
     @Override
     public void setUp() throws Exception {
+        LOG.info("Start setUp");
         super.setUp();
         baseConf.setMetadataServiceUri(zkUtil.getMetadataServiceUri());
         baseClientConf.setMetadataServiceUri(zkUtil.getMetadataServiceUri());
@@ -117,10 +118,12 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
         mFactory = metadataClientDriver.getLedgerManagerFactory();
         underReplicationManager = mFactory.newLedgerUnderreplicationManager();
         ledgerManager = mFactory.newLedgerManager();
+        LOG.info("Finished setUp");
     }
 
     @Override
     public void tearDown() throws Exception {
+        LOG.info("Start tearDown");
         super.tearDown();
 
         if (null != underReplicationManager) {
@@ -138,6 +141,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
         if (null != scheduler) {
             scheduler.shutdown();
         }
+        LOG.info("Finished tearDown");
     }
 
     /**
@@ -146,6 +150,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
      */
     @Test
     public void testOpenLedgers() throws Exception {
+        LOG.info("Start testOpenLedgers");
         List<LedgerHandle> listOfLedgerHandle = createLedgersAndAddEntries(1, 5);
         LedgerHandle lh = listOfLedgerHandle.get(0);
         int ledgerReplicaIndex = 0;
@@ -186,6 +191,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
 
         verifyLedgerEnsembleMetadataAfterReplication(newBookieServer,
                 listOfLedgerHandle.get(0), ledgerReplicaIndex);
+        LOG.info("Finished testOpenLedgers");
     }
 
     /**
@@ -194,6 +200,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
      */
     @Test
     public void testClosedLedgers() throws Exception {
+        LOG.info("Start testClosedLedgers");
         List<Integer> listOfReplicaIndex = new ArrayList<Integer>();
         List<LedgerHandle> listOfLedgerHandle = createLedgersAndAddEntries(1, 5);
         closeLedgers(listOfLedgerHandle);
@@ -247,6 +254,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
                     listOfLedgerHandle.get(index),
                     listOfReplicaIndex.get(index));
         }
+        LOG.info("Finished testClosedLedgers");
     }
 
     /**
@@ -256,6 +264,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
      */
     @Test
     public void testStopWhileReplicationInProgress() throws Exception {
+        LOG.info("Start testStopWhileReplicationInProgress");
         int numberOfLedgers = 2;
         List<Integer> listOfReplicaIndex = new ArrayList<Integer>();
         List<LedgerHandle> listOfLedgerHandle = createLedgersAndAddEntries(
@@ -327,6 +336,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
                     listOfLedgerHandle.get(index),
                     listOfReplicaIndex.get(index));
         }
+        LOG.info("Finished testStopWhileReplicationInProgress");
     }
 
     /**
@@ -336,6 +346,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
      */
     @Test
     public void testNoSuchLedgerExists() throws Exception {
+        LOG.info("Start testNoSuchLedgerExists");
         List<LedgerHandle> listOfLedgerHandle = createLedgersAndAddEntries(2, 5);
         CountDownLatch latch = new CountDownLatch(listOfLedgerHandle.size());
         for (LedgerHandle lh : listOfLedgerHandle) {
@@ -372,6 +383,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
             assertNull("UrLedger still exists after rereplication",
                     watchUrLedgerNode(getUrLedgerZNode(lh), latch));
         }
+        LOG.info("Finished testNoSuchLedgerExists");
     }
 
     /**
@@ -380,6 +392,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
      */
     @Test
     public void testEmptyLedgerLosesQuorumEventually() throws Exception {
+        LOG.info("Start testEmptyLedgerLosesQuorumEventually");
         LedgerHandle lh = bkc.createLedger(3, 2, 2, DigestType.CRC32, PASSWD);
         CountDownLatch latch = new CountDownLatch(1);
         String urZNode = getUrLedgerZNode(lh);
@@ -420,6 +433,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
 
         // should be able to open ledger without issue
         bkc.openLedger(lh.getId(), DigestType.CRC32, PASSWD);
+        LOG.info("Finished testEmptyLedgerLosesQuorumEventually");
     }
 
     /**
@@ -429,6 +443,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
     @Test
     public void testLedgerMetadataContainsIpAddressAsBookieID()
             throws Exception {
+        LOG.info("Start testLedgerMetadataContainsIpAddressAsBookieID");
         stopBKCluster();
         bkc = new BookKeeperTestClient(baseClientConf);
         // start bookie with useHostNameAsBookieID=false, as old bookie
@@ -494,7 +509,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
 
         verifyLedgerEnsembleMetadataAfterReplication(newBookieServer,
                 listOfLedgerHandle.get(0), ledgerReplicaIndex);
-
+        LOG.info("Finished testLedgerMetadataContainsIpAddressAsBookieID");
     }
 
     /**
@@ -504,6 +519,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
     @Test
     public void testLedgerMetadataContainsHostNameAsBookieID()
             throws Exception {
+        LOG.info("Start testLedgerMetadataContainsHostNameAsBookieID");
         stopBKCluster();
 
         bkc = new BookKeeperTestClient(baseClientConf);
@@ -572,7 +588,7 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
 
         verifyLedgerEnsembleMetadataAfterReplication(newBookieServer,
                 listOfLedgerHandle.get(0), ledgerReplicaIndex);
-
+        LOG.info("Finished testLedgerMetadataContainsHostNameAsBookieID");
     }
 
     private int getReplicaIndexInLedger(LedgerHandle lh, BookieId replicaToKill) {
@@ -634,13 +650,13 @@ public class BookieAutoRecoveryTest extends BookKeeperClusterTestCase {
             @Override
             public void process(WatchedEvent event) {
                 if (event.getType() == EventType.NodeDeleted) {
-                    LOG.info("Received Ledger rereplication completion event :"
-                            + event.getType());
+                    LOG.info("Received Ledger replication completion. event : {}, path: {}, latchCount: {}",
+                            event.getType(), event.getPath(), latch.getCount());
                     latch.countDown();
                 }
                 if (event.getType() == EventType.NodeCreated) {
-                    LOG.info("Received urLedger publishing event :"
-                            + event.getType());
+                    LOG.info("Received urLedger publishing event: {}, path: {}, latchCount: {}",
+                            event.getType(), event.getPath(), latch.getCount());
                     latch.countDown();
                 }
             }
