@@ -27,17 +27,21 @@ import io.grpc.EquivalentAddressGroup;
 import io.grpc.NameResolver;
 import io.grpc.NameResolver.Listener;
 import io.grpc.Status;
+import io.grpc.SynchronizationContext;
+import io.grpc.internal.GrpcUtil;
 import java.net.InetSocketAddress;
 import java.net.SocketAddress;
 import java.net.URI;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.stream.Collectors;
 import lombok.Cleanup;
 import org.apache.bookkeeper.conf.ServerConfiguration;
 import org.apache.bookkeeper.discover.BookieServiceInfo;
+import org.apache.bookkeeper.discover.RegistrationManager;
 import org.apache.bookkeeper.meta.MetadataBookieDriver;
 import org.apache.bookkeeper.meta.MetadataDrivers;
 import org.apache.bookkeeper.net.BookieId;
@@ -60,6 +64,7 @@ public class BKRegistrationNameResolverTest extends BookKeeperClusterTestCase {
     private final BKRegistrationNameResolverProvider resolverProvider;
 
     private MetadataBookieDriver bookieDriver;
+    private RegistrationManager regManager;
     private URI serviceUri;
 
     public BKRegistrationNameResolverTest() {
@@ -84,12 +89,14 @@ public class BKRegistrationNameResolverTest extends BookKeeperClusterTestCase {
         ServerConfiguration serverConf = new ServerConfiguration();
         serverConf.setMetadataServiceUri(serviceUri.toString());
         bookieDriver = MetadataDrivers.getBookieDriver(serviceUri);
-        bookieDriver.initialize(serverConf, () -> {}, NullStatsLogger.INSTANCE);
+        bookieDriver.initialize(serverConf, NullStatsLogger.INSTANCE);
+        regManager = bookieDriver.createRegistrationManager();
     }
 
     @After
     @Override
     public void tearDown() throws Exception {
+        regManager.close();
         bookieDriver.close();
 
         super.tearDown();
@@ -103,7 +110,7 @@ public class BKRegistrationNameResolverTest extends BookKeeperClusterTestCase {
         for (int i = 0; i < numServers; i++) {
             InetSocketAddress address = new InetSocketAddress("127.0.0.1", 3181 + i);
             addressSet.add(address);
-            bookieDriver.getRegistrationManager().registerBookie(
+            bookieDriver.createRegistrationManager().registerBookie(
                 BookieId.parse("127.0.0.1:" + (3181 + i)), false, BookieServiceInfo.EMPTY
             );
         }
@@ -112,7 +119,18 @@ public class BKRegistrationNameResolverTest extends BookKeeperClusterTestCase {
 
 
         @Cleanup("shutdown")
-        NameResolver resolver = resolverProvider.newNameResolver(serviceUri, Attributes.EMPTY);
+        NameResolver resolver = resolverProvider.newNameResolver(serviceUri,
+                NameResolver.Args.newBuilder()
+                        .setDefaultPort(0)
+                        .setProxyDetector(GrpcUtil.DEFAULT_PROXY_DETECTOR)
+                        .setSynchronizationContext(new SynchronizationContext((t, ex) -> {}))
+                        .setServiceConfigParser(new NameResolver.ServiceConfigParser() {
+                            @Override
+                            public NameResolver.ConfigOrError parseServiceConfig(Map<String, ?> rawServiceConfig) {
+                                return null;
+                            }
+                        })
+                        .build());
         resolver.start(new Listener() {
             @Override
             public void onAddresses(List<EquivalentAddressGroup> servers, Attributes attributes) {
@@ -138,7 +156,7 @@ public class BKRegistrationNameResolverTest extends BookKeeperClusterTestCase {
         for (int i = numServers; i < 2 * numServers; i++) {
             InetSocketAddress address = new InetSocketAddress("127.0.0.1", 3181 + i);
             addressSet.add(address);
-            bookieDriver.getRegistrationManager().registerBookie(
+            regManager.registerBookie(
                 BookieId.parse("127.0.0.1:" + (3181 + i)), false, BookieServiceInfo.EMPTY
             );
         }
