@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -652,7 +652,10 @@ class BKLogWriteHandler extends BKLogHandler {
         writeLogSegment(txn, l);
 
         // Try storing max sequence number.
-        LOG.debug("Try storing max sequence number in startLogSegment {} : {}", inprogressZnodePath, logSegmentSeqNo);
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("Try storing max sequence number in startLogSegment {} : {}",
+                    inprogressZnodePath, logSegmentSeqNo);
+        }
         storeMaxSequenceNumber(txn, maxLogSegmentSequenceNo, logSegmentSeqNo, true);
 
         txn.execute().whenCompleteAsync(new FutureEventListener<Void>() {
@@ -889,7 +892,9 @@ class BKLogWriteHandler extends BKLogHandler {
             return;
         }
 
-        LOG.debug("Completing and Closing Log Segment {} {}", firstTxId, lastTxId);
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("Completing and Closing Log Segment {} {}", firstTxId, lastTxId);
+        }
         LogSegmentMetadata inprogressLogSegment = readLogSegmentFromCache(inprogressZnodeName);
 
         // validate log segment
@@ -982,7 +987,10 @@ class BKLogWriteHandler extends BKLogHandler {
         // store max sequence number
         storeMaxSequenceNumber(txn, maxLogSegmentSequenceNo, maxSeqNo, false);
         // update max txn id.
-        LOG.debug("Trying storing LastTxId in Finalize Path {} LastTxId {}", pathForCompletedLedger, lastTxId);
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("Trying storing LastTxId in Finalize Path {} LastTxId {}",
+                    pathForCompletedLedger, lastTxId);
+        }
         storeMaxTxId(txn, maxTxId, lastTxId);
 
         txn.execute().whenCompleteAsync(new FutureEventListener<Void>() {
@@ -1096,7 +1104,9 @@ class BKLogWriteHandler extends BKLogHandler {
             LogSegmentMetadata l = logSegments.get(i);
             if (!l.isInProgress()) {
                 if (l.getLastDLSN().compareTo(dlsn) < 0) {
-                    LOG.debug("{}: Truncating log segment {} ", getFullyQualifiedName(), l);
+                    if (LOG.isDebugEnabled()) {
+                        LOG.debug("{}: Truncating log segment {} ", getFullyQualifiedName(), l);
+                    }
                     truncateList.add(l);
                 } else if (l.getFirstDLSN().compareTo(dlsn) < 0) {
                     // Can be satisfied by at most one segment
