@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -639,7 +639,9 @@ public class LogRecord {
                         recordStream.advance(1);
                     }
                 } catch (EOFException eof) {
-                    LOG.debug("Skip encountered end of file Exception", eof);
+                    if (LOG.isDebugEnabled()) {
+                        LOG.debug("Skip encountered end of file Exception", eof);
+                    }
                     break;
                 }
             }
