@@ -55,4 +55,14 @@ public class StateStoreSpec {
     private boolean checkpointChecksumEnable = true;
     @Default
     private boolean checkpointChecksumCompatible = true;
+
+    @Default
+    private boolean localStorageCleanupEnable = false;
+
+    @Default
+    // Max idle time while waiting to restore from a checkpoint.
+    private Duration checkpointRestoreIdleLimit = Duration.ofMinutes(5);
+
+    @Default
+    private int ttlSeconds = 0;
 }
